return {
	newButton = function(number, colour, sound)
		retButton = {}
		retButton.x = buttonUI.edge.x
		if number%2 == 0 then
			retButton.x = retButton.x + buttonUI.space.x + buttonUI.size.x
		end
		retButton.y = buttonUI.edge.y
		if number>2 then
			retButton.y = retButton.y + buttonUI.space.y + buttonUI.size.y
		end
		retButton.size = {}
		retButton.size.x = buttonUI.size.x
		retButton.size.y = buttonUI.size.y
		retButton.colour = colour
		retButton.sound = sound

		return retButton
	end,

	buttonPressed = function(i)
	    v = buttons[i]

		if phase == "show" then
			v.colour = brightColours[i]
			love.audio.stop()
			v.sound:play()
		end

	    if phase == "play" then
	        if i == playSequence:poll() then
				v.colour = brightColours[i]
				love.audio.stop()
				v.sound:play()
	        else
	            score = #sequence-1
	            screen = menuScreen --gameOverScreen
	        end
	    end

	end,

	buttonReleased = function(i)
	    v = buttons[i]
	    v.colour = colours[i]
	end,

	load = function(self)
		math.randomseed(os.time())

		phase = "none"
	    showNextTmr = 1
	    showNextPress = true --or unshow
	    lastPressed = 1

		buttons = {}

		hitSounds = {
			love.audio.newSource("hit1.wav", "static"),
			love.audio.newSource("hit2.wav", "static"),
			love.audio.newSource("hit3.wav", "static"),
			love.audio.newSource("hit4.wav", "static")
		}

		buttonUI = {}
		buttonUI.edge = {x=w/4, y=h/16}
		buttonUI.space = {x=w/16, y=w/16}
		buttonUI.size = {
			x = (w - buttonUI.space.x - buttonUI.edge.x*2)/2,
			y = (h - buttonUI.space.x - buttonUI.edge.y*2)/2,
		}

		for i=1,4 do
			buttons[i] = self.newButton(i, colours[i], hitSounds[i])
		end

		sequence = {}
	    table.insert(sequence, math.random(1,4))

		showSequence = nil
	end,

	draw = function(self)
		for i,v in ipairs(buttons) do
			love.graphics.setColour(v.colour)
			love.graphics.rectangle("fill", v.x, v.y, v.size.x, v.size.y, 20, 20)
		end
	end,

	update = function(self, dt)
		if phase == "none" then
			phase = "show"
		end

		if showSequence == nil then
	        showSequence = List.newQueue()
	        for i,v in ipairs(sequence) do
	            showSequence:enqueue(v)
	        end
	    end
	    if phase == "show" then
	        if showNextTmr <= 0 then
	            if not showSequence:peek() then
					self.buttonReleased(lastPressed)
	                phase = "play"
	                playSequence = nil
	            else
	                if showNextPress == true then
	                    lastPressed = showSequence:poll()
	                    self.buttonPressed(lastPressed)
	                    showNextPress = false
	                    showNextTmr = 0.2
	                else
	                    self.buttonReleased(lastPressed)
	                    showNextPress = true
	                    showNextTmr = 0.2
	                end
	            end
	        else
	            showNextTmr = showNextTmr - dt
	        end
	    elseif phase == "play" then
	        if playSequence == nil then
	            playSequence = List.newQueue()
	            for i,v in ipairs(sequence) do
	                playSequence:enqueue(v)
	            end
	        end
	        if playSequence:peek() == nil then
	            phase = "show"
	            table.insert(sequence, math.random(1, 4))
	            showSequence = nil
	        end
	    end
	end,

	mousepressed = function(self, x, y, button, istouch)
		if phase == "play" then
			for i,v in ipairs(buttons) do
				if x > v.x and x < v.x+v.size.x and y > v.y and y < v.y+v.size.y then
					self.buttonPressed(i)
				end
			end
		end
	end,

	mousereleased = function(self, x, y, button, istouch)
		for i,v in ipairs(buttons) do
			buttons[i].colour = colours[i]
		end
	end,

	keypressed = function(self, key)
		if key == "escape" then
			score = #sequence-1
			screen = menuScreen
		end
	end
}
